
# Slot: has temporal context


a constraint of time placed upon the truth value of an association.

URI: [biolink:has_temporal_context](https://w3id.org/biolink/vocab/has_temporal_context)


## Domain and Range

[Association](Association.md) &#8594;  <sub>0..1</sub> [TimeType](types/TimeType.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children


## Used by

 * [ExposureEventToOutcomeAssociation](ExposureEventToOutcomeAssociation.md)
